package
Version:
v0.0.5
Opens a new window with list of versions in this module.
Published: Jun 20, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Cache struct {
Entries map[string]cacheEntry
}
Cache includes a mutex because maps aren't
concurrency safe
NewCache creates a new Cache to be used
during the session
Add creates a new entry in the cache
Get attempts to retrieve an entry from the cache
Source Files
¶
Click to show internal directories.
Click to hide internal directories.